pub struct TgmBufferIter { /* private fields */ }Expand description
Opaque handle for iterating over messages in a byte buffer.
The caller’s buffer must remain valid for the lifetime of this iterator.